:py:mod:`user_input_com`
========================

.. py:module:: user_input_com


Module Contents
---------------

.. py:data:: current_dir
   

   

.. py:data:: current_dir
   

   

.. py:data:: Exec
   

   Properties of the generated Node


.. py:data:: BaseName
   :annotation: = User Input

   

.. py:data:: NodeAttributeNames
   :annotation: = ['Parameters', 'Text Out']

   

.. py:data:: NodeAttributeType
   :annotation: = ['Static', 'Output']

   

.. py:data:: ParameterNames
   :annotation: = ['Visualisation', 'Output Type', 'User Input']

   

.. py:data:: ParameterTypes
   :annotation: = ['bool', 'list', 'str']

   

.. py:data:: ParametersDefaultValues
   :annotation: = [False, ['string', 'int', 'float'], '']

   

.. py:data:: WorkerDefaultExecutable
   

   

.. py:data:: user_input_com
   

   

